@@ -21,6 +21,7 @@ gateway_base_aio.py
 """
 
 import asyncio
+import sys
 from python_banyan.banyan_base_aio import BanyanBaseAIO
 
 
@@ -70,10 +71,13 @@ class GatewayBaseAIO(BanyanBaseAIO):
         if board_type:
             self.board_type = board_type
 
-        # set up the event loop
         if event_loop:
             self.event_loop = event_loop
+
+        # fix for "not implemented" bugs in Python 3.8
         else:
+            if sys.platform == 'win32':
+                asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
             self.event_loop = asyncio.get_event_loop()
 
         if subscriber_list:
@@ -155,12 +159,9 @@ class GatewayBaseAIO(BanyanBaseAIO):
         try:
             command = payload['command']
         except KeyError:
-            print(payload)
+            print('incoming_message_processed KeyErrer', payload)
             raise
 
-        # pin = None
-        # tag = ''
-
         # if a tag is provided and the tag is in the dictionary, fetch
         # the associated pin number
         if 'tag' in payload:
@@ -172,19 +173,6 @@ class GatewayBaseAIO(BanyanBaseAIO):
                     payload['pin'] = pin
                 else:
                     self.tags_dictionary[payload['tag']] = payload['pin']
-        else:
-            tag = ''
-
-        # try:
-        #     if pin is not None:
-        #         pin = int(payload['pin'])
-
-            # if self.pins_dictionary:
-            #     pin_record = self.pins_dictionary[pin]
-            # else:
-            #     raise RuntimeError('Set pin mode before using pin')
-        # except KeyError:
-        #     raise KeyError('pin record not found')
 
         # if command is in the command dictionary, execute the command
         if command in self.command_dictionary.keys():
@@ -194,6 +182,9 @@ class GatewayBaseAIO(BanyanBaseAIO):
         else:
             await self.additional_banyan_messages(topic, payload)
 
+    # all of the following methods should be overridden in the hardware
+    # specific gateway when being used.
+
     async def additional_banyan_messages(self, topic, payload):
         """
         This method will pass any messages not handled by this class to the
